@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -20,9 +20,7 @@ KNotesWidget::KNotesWidget(KNotesPart *part, QWidget *parent)
     lay->addWidget(mIconView);
 }
 
-KNotesWidget::~KNotesWidget()
-{
-}
+KNotesWidget::~KNotesWidget() = default;
 
 void KNotesWidget::slotFocusQuickSearch()
 {
